edd_plot_branch: Generating boxplots of various tree branching measures

edd_plot_branchR Documentation

Generating boxplots of various tree branching measures

Description

Function to generate boxplots showing the meaning branch lengths of the trees.

Usage

edd_plot_branch(
  raw_data = NULL,
  method = "treestats",
  save_plot = FALSE,
  path = NULL
)

Arguments

raw_data

a list of results generated by edd simulation function

method

Specify which package to be used to calculate statistics

save_plot

Logical, whether save to file or return a ggplot object

path

Path to save the plot

Value

an ggplot object

Author(s)

Tianjian Qin


EvoLandEco/eve documentation built on Sept. 14, 2024, 12:04 a.m.