Learn R Programming

eve (version 1.0)

eve-package: The Eigenvalues Entropy as a Classifier Evaluation Measure

Description

eve allows to compute the eigenvalues entropy and many other commonly used classifier evaluation measures. For comparison purpose, all measures computed are adjusted to vary in [0,1].

Arguments

Author

Doulaye Dembele Maintainer: Doulaye Dembele <doulaye@igbmc.fr>

Details

Package:eve
Type:Package
Version:0.1-0
Date:2025-10-20
License:GPL (>=2.0)

This package has the following functions:

eve():The function allowing to compute the eigenvalues entropy measure.
eve.mmatt():This function allows to compute a modified confusion matrix
which is useful for imbalanced problem.
eve.bounds():This function allows to compute lower and upper bound values for the eigenvalues
used to get the EVE evaluation measure.
eve.eigens():This function gives access to the eigenvalues used to get the EVE evaluation measure.
eve.bival():This function allows to compute the sensitivity, the specificity, the precision, the
Fowlkes and Mallows index, the F1-score and the area under the ROC curve, for a binary problem.
eve.acc():The function computes the accuracy.
eve.nmi():This function computes the normalized mutual information value.
eve.mcc():This function computes the Matthews correlation coefficient, a shifted value is returned.
eve.kappa():This function computes the Cohen's Kappa measure value.
eve.cen():This function computes the confusion entropy of the misclassification.
A shifted value is returned.
eve.mcen():This function compute the modified confusion entropy of the misclassification.
A shifted value is returned.
m2two():This function converts a multiclass confusion matrix into a binary confusion matrix.
m2two.k():This function allows to get a confusion matrix of the comparison of one class
(k) versus the others.

References

Dembele D. (2025), The Eigenvalues Entropy as a Classifier Evaluation Measure. arXiv:2511.01904

Examples

Run this code
   mmat <- matrix(c(50,0,0,0,35,15,0,7,43),ncol=3)

   eve(mmat)
   eve.acc(mmat)
   eve.kappa(mmat)
   eve.mcc(mmat)
   eve.nmi(mmat)
   eve.cen(mmat)
   eve.mcen(mmat)

   eve.mmatt(mmat)
   
   res <- m2two(mmat)
   eve.bival(res)
   eve.kappa(res)
   eve(res)

   res <- m2two.k(mmat,2)
   eve.bival(res)
   eve.mcc(res)
   eve.acc(res)
   
   mmat <- matrix(c(9,1,80,210),ncol=2)
   eve.bival(mmat)
   eve.bival(eve.mmatt(mmat))
   eve(mmat)
   eve(eve.mmatt(mmat))

Run the code above in your browser using DataLab