Learn R Programming

eve (version 1.0)

eve.acc: Accuracy calculation

Description

This function computes the accuracy for a binary or amulticlass confusion matrix.

Usage

eve.acc(mmat)

Value

This function returns a numerical value, the accuracy associated with the confusion matrix.

Arguments

mmat

a square numerical-valued confusion matrix.

Author

Doulaye Dembele

References

E.B. Fowlkes and C.L. Mallows. A method for Comparing Two Hierarchical Clusterings.
J Am Stat Assoc, 1983, v78, n383, pp553-569

A.K. Jain and R. Dubes. Algorithms for Clustering Data.
Prentice Hall, Englewood, New Jersey, 1988.

Examples

Run this code
   mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3)
   eve.acc(mmat)

Run the code above in your browser using DataLab