Learn R Programming

eve (version 1.0)

eve.bival: Some binary measures calculation

Description

This function computes the sensitivity, the specificity, the precision, the Fowlkes & Mallows index, the F1-score and the area under the ROC curve for a binary problem confusion matrix.

Usage

eve.bival(mmat)

Value

This function returns the sensitivity, the specificity, the precision, the Fowlkes & Mallows index, the F1-score and the area under the ROC curve measure values.

Arguments

mmat

a 2 x 2 numerical-valued confusion matrix.

Author

Doulaye Dembele

References

H. Cramer. Mathematical Methods of Statistics.
Princeton Univ Press, 1946.

E.B. Fowlkes and C.L. Mallows. A method for Comparing Two Hierarchical Clusterings.
J Am Stat Assoc, 1983, v78, n383, pp553-569

A.K. Jain and R. Dubes. Algorithms for Clustering Data.
Prentice Hall, Englewood, New Jersey, 1988.

J. Furnkranz and P.A. Flach. ROC'n' Rule Learning - Towards a Better Understanding of Covering Algorithms.
Mach Learn, 2005, v58, pp39-77.

D.J. Hand. Measuring Classifier Performance: a Coherent Alternative to the Area Under the ROC Curve.
Mach Learn, 2009, v77, pp367-374.

D.M.W. Powers. Evaluation from Precision, Recall and F-measure to ROC, Informmedness, Markedness and Correlation.
arXiv, 2020, 2010.16061.

Examples

Run this code
   mmat <- matrix(c(434,10,7,232), ncol=2)
   eve.bival(mmat)

Run the code above in your browser using DataLab