Learn R Programming

eve (version 1.0)

eve.cen: Confusion entropy calculation

Description

This function computes the confusion entropy for a binary or a multiclass confusion matrix. A shifted value is returned

Usage

eve.cen(mmat)

Value

This function returns a numerical value, a shifted confusion entropy (1-CEN).

Arguments

mmat

a square numerical-valued confusion matrix.

Author

Doulaye Dembele

References

J.M. Wei, X.J. Yuan, Q.H. Hu and S.Q. Wang. A Novel Measure for Evaluating Classifiers.
Expert Syst Appl, 2010, v15 pp4969-4992.

Examples

Run this code
   mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3)
   eve.cen(mmat)

Run the code above in your browser using DataLab