Learn R Programming

eve (version 1.0)

eve.eigens: Eigenvalues used in the EVE measure

Description

This function give access to the eigenvalues associated with a confusion matrix transformation.

Usage

eve.eigens(mmat)

Value

This function returns the eigenvalues of the confusion matrix transformation. These eigenvalues are used to obtain the EVE evaluation measure. For a binary problem, they can be used to obtain the AUC or the Gini index (coefficient).

Arguments

mmat

a square numerical-valued confusion matrix.

Author

Doulaye Dembele

References

Dembele D. (2025), The Eigenvalues Entropy as a Classifier Evaluation Measure. arXiv:2511.01904

Examples

Run this code
   mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3)
   eve.eigens(mmat)

Run the code above in your browser using DataLab