Learn R Programming

eve (version 1.0)

eve.mcen: Modified confusion entropy calculation

Description

This function computes the modified confusion entropy for a binary or a multiclass confusion matrix. A shifted value is returned

Usage

eve.mcen(mmat)

Value

This function returns a numerical value, a shifted modified confusion entropy (1-MCEN).

Arguments

mmat

a square numerical-valued confusion matrix.

Author

Doulaye Dembele

References

R. Delgado and J.D. Nunez-Gonzalez. Enhancing Confusion Entropy CEN for Binary and Multiclass Classification.
PLoS One, 2019, v14, n1, e0210264.

Examples

Run this code
   mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3)
   eve.mcen(mmat)

Run the code above in your browser using DataLab