Learn R Programming

eve (version 1.0)

eve.mmatt: Modified confusion matrix calculation

Description

This function computes a modified confusion matrix for a binary or a multiclass problem.

Usage

eve.mmatt(mmat)

Value

This function returns a modified confusion matrix which can be used to improve a measure sensitive to imbalanced ratio.

Arguments

mmat

a square numerical-valued confusion matrix.

Author

Doulaye Dembele

References

Dembele D. (2025), The Eigenvalues Entropy as a Classifier Evaluation Measure. arXiv:2511.01904

Examples

Run this code
   mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3)
   eve.mmatt(mmat)

Run the code above in your browser using DataLab