Learn R Programming

eve (version 1.0)

eve.nmi: Normalized mutual information calculation

Description

This function computes the normalized mutual information for a binary or a multiclass confusion matrix.

Usage

eve.nmi(mmat)

Value

This function returns a numerical value, the normalized mutual information.

Arguments

mmat

a square numerical-valued confusion matrix.

Author

Doulaye Dembele

References

T.M. Cover and J.A. Thomas. Elements of Information Theory.
Wiley, 2006, 2nd edition, Hoboken, New Jersey.

I. Kononenko and I Bratko. Information-Based Evaluation Criterion of Classifiers Performance.
Mach Learn, 1991, v6, pp67-80.

N.X. Vinh, J. Epps and J. Bailey. Information Theoretic Measures for Clusterings Comparison: Variants, Properties, Normalization and Correction for Chance.
J Mach Learn Res, 2010, v11 pp2837-2854.

Examples

Run this code
   mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3)
   eve.nmi(mmat)

Run the code above in your browser using DataLab