phylo2mpd: Converting a phylogenetic tree of phylo object to mean...

View source: R/edd_sim_utilities.R

phylo2mpdR Documentation

Converting a phylogenetic tree of phylo object to mean pairwise distance among all tips

Description

Function to convert a phylogenetic tree with extant species to mean pairwise distance

Usage

phylo2mpd(phy)

Arguments

phy

a phylo object that only contains extant species extinct at the present

Value

a numeric value of mean pairwise distance

Author(s)

Tianjian Qin


EvoLandEco/eve documentation built on Sept. 14, 2024, 12:04 a.m.