| edd_plot_branch | R Documentation |
Function to generate boxplots showing the meaning branch lengths of the trees.
edd_plot_branch(
raw_data = NULL,
method = "treestats",
save_plot = FALSE,
path = NULL
)
raw_data |
a list of results generated by edd simulation function |
method |
Specify which package to be used to calculate statistics |
save_plot |
Logical, whether save to file or return a ggplot object |
path |
Path to save the plot |
an ggplot object
Tianjian Qin
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.