This function computes a lower and an upper bound
values for the eigenvalues associated with a confusion matrix
transformation.
Usage
eve.bounds(mmat)
Value
This function returns a vector which entries are
a lower and an upper bound for the eigenvalues associated
with a confusion matrix transformation. The range of these
bounds is small (<2) for a good classifier.
Arguments
mmat
a square numerical-valued confusion matrix.
Author
Doulaye Dembele
References
Dembele D. (2025), The Eigenvalues Entropy as a
Classifier Evaluation Measure. arXiv:2511.01904