powered by
This function computes the confusion entropy for a binary or a multiclass confusion matrix. A shifted value is returned
eve.cen(mmat)
This function returns a numerical value, a shifted confusion entropy (1-CEN).
a square numerical-valued confusion matrix.
Doulaye Dembele
J.M. Wei, X.J. Yuan, Q.H. Hu and S.Q. Wang. A Novel Measure for Evaluating Classifiers. Expert Syst Appl, 2010, v15 pp4969-4992.
mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3) eve.cen(mmat)
Run the code above in your browser using DataLab