powered by
This function computes the Cohen's kappa measure for a binary or a multiclass confusion matrix.
eve.kappa(mmat)
This function returns a numerical value, the Cohen kappa evaluation measure.
a square numerical-valued confusion matrix.
Doulaye Dembele
J. Cohen. A Coefficient of Agreement for Nominal Scales. Educ Psychol Meas, 1960, v20 n1 pp37-46
mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3) eve.kappa(mmat)
Run the code above in your browser using DataLab