powered by
This function computes the Matthews' correlation cooefficient for a binary of a multiclass confusion matrix.
eve.mcc(mmat)
This function returns a numerical value, a shifted Matthews correlation coefficient which varies in [0,1].
a square numerical-valued confusion matrix.
Doulaye Dembele
B.W. Matthews. Comparison of the Predicted and observed Secondary Structures of T4 Phage Lysozome. Biochem Biophys Acta, 1975, v405 pp442-451.
J. Gorodkin. Comparing Two K-Category Assignments by a K-Category Correlation Coefficient. Comput Biol Chem, 2004, v28 pp367-374.
mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3) eve.mcc(mmat)
Run the code above in your browser using DataLab