powered by
This function computes a modified confusion matrix for a binary or a multiclass problem.
eve.mmatt(mmat)
This function returns a modified confusion matrix which can be used to improve a measure sensitive to imbalanced ratio.
a square numerical-valued confusion matrix.
Doulaye Dembele
Dembele D. (2025), The Eigenvalues Entropy as a Classifier Evaluation Measure. arXiv:2511.01904
mmat <- matrix(c(50,0,0,0,35,15,0,7,34), ncol=3) eve.mmatt(mmat)
Run the code above in your browser using DataLab