View source: R/edd_sim_utilities.R
| phylo2mpd | R Documentation |
Function to convert a phylogenetic tree with extant species to mean pairwise distance
phylo2mpd(phy)
phy |
a phylo object that only contains extant species extinct at the present |
a numeric value of mean pairwise distance
Tianjian Qin
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.